@@ -20,6 +20,7 @@ from ._compat import (
     NullFinder,
     PyPy_repr,
     install,
+    pypy_partial,
 )
 from ._functools import method_cache
 from ._itertools import unique_everseen
@@ -245,7 +246,7 @@ class DeprecatedList(list):
         warnings.warn,
         "EntryPoints list interface is deprecated. Cast to list if needed.",
         DeprecationWarning,
-        stacklevel=2,
+        stacklevel=pypy_partial(2),
     )
 
     def __setitem__(self, *args, **kwargs):
@@ -338,7 +339,7 @@ class EntryPoints(DeprecatedList):
         """
         Return the set of all names of all entry points.
         """
-        return set(ep.name for ep in self)
+        return {ep.name for ep in self}
 
     @property
     def groups(self):
@@ -349,7 +350,7 @@ class EntryPoints(DeprecatedList):
         >>> EntryPoints().groups
         set()
         """
-        return set(ep.group for ep in self)
+        return {ep.group for ep in self}
 
     @classmethod
     def _from_text_for(cls, text, dist):
@@ -367,14 +368,6 @@ class EntryPoints(DeprecatedList):
         )
 
 
-def flake8_bypass(func):
-    # defer inspect import as performance optimization.
-    import inspect
-
-    is_flake8 = any('flake8' in str(frame.filename) for frame in inspect.stack()[:5])
-    return func if not is_flake8 else lambda: None
-
-
 class Deprecated:
     """
     Compatibility add-in for mapping to indicate that
@@ -402,7 +395,7 @@ class Deprecated:
         warnings.warn,
         "SelectableGroups dict interface is deprecated. Use select.",
         DeprecationWarning,
-        stacklevel=2,
+        stacklevel=pypy_partial(2),
     )
 
     def __getitem__(self, name):
@@ -410,7 +403,7 @@ class Deprecated:
         return super().__getitem__(name)
 
     def get(self, name, default=None):
-        flake8_bypass(self._warn)()
+        self._warn()
         return super().get(name, default)
 
     def __iter__(self):
@@ -1020,6 +1013,18 @@ def packages_distributions() -> Mapping[str, List[str]]:
     """
     pkg_to_dist = collections.defaultdict(list)
     for dist in distributions():
-        for pkg in (dist.read_text('top_level.txt') or '').split():
+        for pkg in _top_level_declared(dist) or _top_level_inferred(dist):
             pkg_to_dist[pkg].append(dist.metadata['Name'])
     return dict(pkg_to_dist)
+
+
+def _top_level_declared(dist):
+    return (dist.read_text('top_level.txt') or '').split()
+
+
+def _top_level_inferred(dist):
+    return {
+        f.parts[0] if len(f.parts) > 1 else f.with_suffix('').name
+        for f in dist.files
+        if f.suffix == ".py"
+    }
